""" version which can be consumed from within the module """
VERSION_STR = "0.1.62"
DESCRIPTION = "pyawskit is a collection of utilities to help interact with aws"
APP_NAME = "pyawskit"
LOGGER_NAME = "pyawskit"
